@@ -43,7 +43,6 @@ $GLOBALS['ConfigFile']->setPersistKeys(
         'Servers/1/host',
         'Servers/1/port',
         'Servers/1/socket',
-        'Servers/1/extension',
         'Servers/1/connect_type',
         'Servers/1/auth_type',
         'Servers/1/user',
@@ -54,4 +53,3 @@ $GLOBALS['ConfigFile']->setPersistKeys(
 // allows for redirection even after sending some data
 ob_start();
 
-?>
